<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr_BE">
<context>
    <name>EditShare</name>
    <message>
        <location filename="../src/editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Boîte de dialogue</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>&amp;Nom</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="30"/>
        <source>...</source>
        <translation> …</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>&amp;Chemin d’accès</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="56"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>&amp;Description</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>&amp;Autoriser l’accès aux invités</translation>
    </message>
    <message>
        <location filename="../src/editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Droits d’accès pour les utilisateurs•rices autorisés•es</translation>
    </message>
    <message>
        <location filename="../src/editshare.cpp" line="52"/>
        <source>Select directory to share</source>
        <translation>Choisir le répertoire à partager</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>&amp;Partages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Partages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aucun partage utilisateur•rice samba trouvé&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="50"/>
        <location filename="../src/mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <location filename="../src/mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Éditer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Chemin d’accès</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>Permissions</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Autoriser l’accès aux invités</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>&amp;Utilisateurs•rices</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Aucun•e utilisateur•rice samba détecté•e&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>&amp;Mot de passe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Utilisateurs•rices</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="346"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>&amp;Activer le démarrage automatique de Samba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="226"/>
        <location filename="../src/mainwindow.cpp" line="301"/>
        <location filename="../src/mainwindow.cpp" line="356"/>
        <source>Star&amp;t Samba</source>
        <translation>&amp;Démarrer Samba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>Le service de démarrage automatique Samba est désactivé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="285"/>
        <location filename="../src/mainwindow.cpp" line="302"/>
        <source>Samba is running</source>
        <translation>Samba est en cours d’exécution</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>À&amp;propos de …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="333"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="365"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="368"/>
        <source>&amp;Help</source>
        <translation>A&amp;ide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="374"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="409"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="412"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="418"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="104"/>
        <location filename="../src/mainwindow.cpp" line="109"/>
        <location filename="../src/mainwindow.cpp" line="136"/>
        <location filename="../src/mainwindow.cpp" line="147"/>
        <location filename="../src/mainwindow.cpp" line="203"/>
        <location filename="../src/mainwindow.cpp" line="285"/>
        <location filename="../src/mainwindow.cpp" line="296"/>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <location filename="../src/mainwindow.cpp" line="427"/>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <location filename="../src/mainwindow.cpp" line="437"/>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="487"/>
        <location filename="../src/mainwindow.cpp" line="495"/>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <location filename="../src/mainwindow.cpp" line="533"/>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <location filename="../src/mainwindow.cpp" line="567"/>
        <location filename="../src/mainwindow.cpp" line="582"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="104"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Erreur, impossible d’ajouter un partage. Nom de partage vide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="101"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="109"/>
        <source>Path: %1 does not exist.</source>
        <translation>Le chemin: %1 n’existe pas.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="137"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>Impossible d’ajouter un partage. Message d’erreur:

%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="147"/>
        <source>Error listing users</source>
        <translation>Erreur dans la liste des utilisateurs•rices</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>&amp;Deny</source>
        <translation>&amp;Refuser</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>&amp;Read Only</source>
        <translation>&amp;Lecture seulement</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>&amp;Full Access</source>
        <translation>&amp;Accès complet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="203"/>
        <source>Error listing shares</source>
        <translation>Erreur de listing des partages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="286"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>Votre utilisateur•rice n’appartient pas au groupe « sambashare ». Si vous venez d’installer l’application, vous devrez peut-être redémarrer le système.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="296"/>
        <source>Samba is not installed</source>
        <translation>Samba n’est pas installé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="301"/>
        <source>Sto&amp;p Samba</source>
        <translation>Sto&amp;p Samba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="302"/>
        <source>Samba is not running</source>
        <translation>Samba est inactif</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="303"/>
        <source>Samba autostart is enabled</source>
        <translation>Le démarrage automatique Samba est activé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="303"/>
        <source>Samba autostart is disabled</source>
        <translation>Le démarrage automatique Samba est désactivé</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="304"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>&amp;Désactiver le démarrage automatique Samba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>MX Samba Config</source>
        <translation>MX Samba configuration</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="372"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="374"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Programme pour la configuration des partages et des utilisateurs•rices Samba.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="376"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="377"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="384"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>Cannot delete user: </source>
        <translation>Impossible de supprimer l’utilisateur•rice: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="404"/>
        <source>Enter the username and password:</source>
        <translation>Entrez le nom d’utilisateur•rice et le mot de passe:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="411"/>
        <source>Username:</source>
        <translation>Nom d’utilisateur•rice:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="412"/>
        <location filename="../src/mainwindow.cpp" line="468"/>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="413"/>
        <location filename="../src/mainwindow.cpp" line="469"/>
        <source>Confirm password:</source>
        <translation>Confirmer le mot de passe:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="427"/>
        <source>Empty username, please enter a name.</source>
        <translation>Nom d’utilisateur•rice vide, veuillez entrer un nom.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>Utilisateur•rice linux non trouvé•e sur le système, veuillez entrer un nom d’utilisateur•rice valide.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="437"/>
        <location filename="../src/mainwindow.cpp" line="487"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Les mots de passe ne correspondent pas, veuillez entrer à nouveau.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="444"/>
        <source>Could not add user.</source>
        <translation>Impossible d’ajouter un•e utilisateur•rice.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="455"/>
        <location filename="../src/mainwindow.cpp" line="505"/>
        <location filename="../src/mainwindow.cpp" line="511"/>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="455"/>
        <source>No user selected.</source>
        <translation>Aucun•e utilisateur•rice sélectionné•e.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="462"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>Changer le mot de passe de « %1 »</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <source>Password fields cannot be empty.</source>
        <translation>Les champs du mot de passe ne peuvent pas être vides.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="495"/>
        <source>Could not change password.</source>
        <translation>Impossible de changer le mot de passe.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="505"/>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <source>No share selected.</source>
        <translation>Aucun partage sélectionné.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="511"/>
        <source>Selected share is empty.</source>
        <translation>Le partage sélectionné est vide.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>Cannot delete share: </source>
        <translation>Impossible de supprimer le partage: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="521"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="521"/>
        <source>Share deleted successfully: </source>
        <translation>Le partage a bien été supprimé: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="534"/>
        <location filename="../src/mainwindow.cpp" line="583"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>Le service Samba est inactif. Veuillez démarrer Samba avant d’ajouter ou de modifier des partages</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <location filename="../src/mainwindow.cpp" line="567"/>
        <source>Error processing permissions: </source>
        <translation>Erreur dans le traitement des autorisations: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="45"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="46"/>
        <location filename="../src/about.cpp" line="55"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="47"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="67"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez exécuter cette application en tant qu’utilisateur•rice normal•e.</translation>
    </message>
</context>
</TS>